@@ -2,7 +2,7 @@ from pydantic import BaseModel  # pylint: disable=no-name-in-module
 
 from ..entities.dispatcher import BaseDispatcher
 from ..entities.event import BaseEvent
-from ..interfaces.dispatcher import DispatcherInterface
+from ..abstract.interfaces.dispatcher import IDispatcherInterface
 
 
 class ExceptionThrowed(BaseEvent, BaseModel):
@@ -11,7 +11,7 @@ class ExceptionThrowed(BaseEvent, BaseModel):
 
     class Dispatcher(BaseDispatcher):
         @staticmethod
-        def catch(interface: DispatcherInterface):
+        def catch(interface: IDispatcherInterface):
             if interface.annotation == interface.event.exception.__class__:
                 return interface.event.exception
             if interface.name == "event":
